==> cv-react-library-0.1.12.tgz: package/src/components/web/DropDown/DropDown.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { createMuiTheme, Select, FormControl, MenuItem } from '@material-ui/core';
import { ThemeProvider } from '@material-ui/styles';

// Styles
import getStyles from './DropDown.styles';

/**
 * Dropdown component that allows a user to select an option from a pre-defined menu of options.
 * @see https://material-ui.com/demos/selects/
 */
const DropDown = (props) => {
    const {
        contextStyles,
        items,
        disabled,
        testID,
        value,
        onChange,
        renderItem,
        renderValue,
    } = props;

    const styles = getStyles(contextStyles);
    const theme = createMuiTheme({
        overrides: {
            MuiMenu: {
                paper: {
                    ...styles.menu,
                },
            },
            MuiMenuItem: {
                root: {
                    ...styles.menuOptions,
                    '&$selected': {
                        ...styles.selectedItem,
                    },
                },
            },
        },
        typography: {
            useNextVariants: true,
        },
    });

    return (
        <ThemeProvider theme={ theme }>
            <FormControl
                style={ styles.container }
                data-testid={ testID && `${testID}__container` }>
                <Select
                    data-testid={ testID && `${testID}__select` }
                    value={ value }
                    renderValue={ renderValue }
                    onChange={ onChange }
                    disabled={ disabled }>
                    { items.length === 0 && (
                        <MenuItem value="">
                            (empty)
                        </MenuItem>
                    ) }
                    { items.map((item) => renderItem(MenuItem, item)) }
                </Select>
            </FormControl>
        </ThemeProvider>

    );
};

DropDown.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container */
        container: PropTypes.object,

        /** Styles for the menu */
        menu: PropTypes.object,

        /** Styles for the menu options */
        menuOptions: PropTypes.object,

        /** Styles for the Selected Item in the menu */
        selectedItem: PropTypes.object,
    }),

    /** An array of drop down menu items */
    items: PropTypes.array,

    /** Disable the dropdown */
    disabled: PropTypes.bool,

    /**
     * Called when change event occurs on the dropdown
     * @param {Event} event - The change event
     */
    onChange: PropTypes.func.isRequired,

    /**
     * Called to render the menu items
     * @param {Component} MenuItem - The default menu item component
     * @param {any} Item - Item that needs to be rendered
     */
    renderItem: PropTypes.func.isRequired,

    /** Selected Item value */
    value: PropTypes.string,

    /**
     * Function that is used to render a custom selected option
     * @param {any} value - The current selected item.
     */
    renderValue: PropTypes.func.isRequired,

    /** Id used for testing */
    testID: PropTypes.string,
};

DropDown.defaultProps = {
    contextStyles: {},
    value: '',
    items: [],
};

export default DropDown;

==> cv-react-library-0.1.29.tgz: package/src/components/web/DropDown/DropDown.js <==
import React, { useState } from 'react';
import PropTypes from 'prop-types';
import { createMuiTheme, Select, FormControl, MenuItem } from '@material-ui/core';
import { ThemeProvider } from '@material-ui/styles';

// Styles
import getStyles from './DropDown.styles';

/**
 * Dropdown component that allows a user to select an option from a pre-defined menu of options.
 * @see https://material-ui.com/demos/selects/
 */
const DropDown = (props) => {
    const [
        open,
        setOpen,
    ] = useState(true);

    const {
        contextStyles,
        items,
        disabled,
        testID,
        value,
        onChange,
        renderItem,
        renderValue,
        autoFocus,
    } = props;

    const autoFocusProps = autoFocus && {
        open,
        onClose: () => setOpen(false),
        onOpen: () => setOpen(true),
        autoFocus: open,
    };

    const styles = getStyles(contextStyles);
    const theme = createMuiTheme({
        overrides: {
            MuiMenu: {
                paper: {
                    ...styles.menu,
                },
            },
            MuiMenuItem: {
                root: {
                    ...styles.menuOptions,
                    '&$selected': {
                        ...styles.selectedItem,
                    },
                },
            },
        },
        typography: {
            useNextVariants: true,
        },
    });

    return (
        <ThemeProvider theme={ theme }>
            <FormControl
                style={ styles.container }
                data-testid={ testID && `${testID}__container` }>
                <Select
                    data-testid={ testID && `${testID}__select` }
                    value={ value }
                    renderValue={ renderValue }
                    onChange={ onChange }
                    disabled={ disabled }
                    { ...autoFocusProps }>
                    { items.length === 0 && (
                        <MenuItem value="">
                            (empty)
                        </MenuItem>
                    ) }
                    { items.map((item) => renderItem(MenuItem, item)) }
                </Select>
            </FormControl>
        </ThemeProvider>

    );
};

DropDown.propTypes = {
    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container */
        container: PropTypes.object,

        /** Styles for the menu */
        menu: PropTypes.object,

        /** Styles for the menu options */
        menuOptions: PropTypes.object,

        /** Styles for the Selected Item in the menu */
        selectedItem: PropTypes.object,
    }),

    /** An array of drop down menu items */
    items: PropTypes.array,

    /** Disable the dropdown */
    disabled: PropTypes.bool,

    /**
     * Called when change event occurs on the dropdown
     * @param {Event} event - The change event
     */
    onChange: PropTypes.func.isRequired,

    /**
     * Called to render the menu items
     * @param {Component} MenuItem - The default menu item component
     * @param {any} Item - Item that needs to be rendered
     */
    renderItem: PropTypes.func.isRequired,

    /** Selected Item value */
    value: PropTypes.string,

    /**
     * Function that is used to render a custom selected option
     * @param {any} value - The current selected item.
     */
    renderValue: PropTypes.func.isRequired,

    /** Id used for testing */
    testID: PropTypes.string,

    /** Auto focus the dropdown menu */
    autoFocus: PropTypes.bool,
};

DropDown.defaultProps = {
    contextStyles: {},
    value: '',
    items: [],
};

export default DropDown;
